"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable @typescript-eslint/no-unsafe-call */
/* eslint-disable @typescript-eslint/no-unsafe-member-access */
/* eslint-disable @typescript-eslint/no-unsafe-assignment */
const commander_1 = require("commander");
const bundles_1 = require("./bundles");
const analysis_1 = require("./analysis");
const http_1 = require("./http");
const emitter_1 = require("./emitter");
function parseConnectionOptions(options) {
    var _a;
    let headers = {};
    if ((_a = options.headers) === null || _a === void 0 ? void 0 : _a.length) {
        headers = options.headers.reduce((m, h) => {
            const [key, value] = h.split(':');
            m[key.trim()] = value.trim();
            return m;
        }, {});
    }
    return {
        baseURL: options.url,
        sessionToken: options.token,
        source: options.source,
        ...(options.org ? { org: options.org } : {}),
        ...(options.orgId ? { orgId: options.orgId } : {}),
        extraHeaders: headers,
        // requestId?: string; - not supported
    };
}
async function filtersAction(options) {
    const response = await bundles_1.getSupportedFiles(options.url, options.source, undefined, [], options.orgId);
    console.log(JSON.stringify(response, null, 2));
}
async function createBundleAction(options) {
    var _a, _b, _c;
    const opts = {
        ...parseConnectionOptions(options),
        paths: options.path,
        ...(((_a = options.ignore) === null || _a === void 0 ? void 0 : _a.length) ? { defaultFileIgnores: options.ignore } : {}),
    };
    let bundle = null;
    if ((_b = options.patterns) === null || _b === void 0 ? void 0 : _b.length) {
        bundle = await bundles_1.createBundleWithCustomFiles(opts, { configFiles: [], extensions: (_c = options.patterns) !== null && _c !== void 0 ? _c : [] });
    }
    else {
        bundle = await bundles_1.createBundleFromFolders(opts);
    }
    if (bundle === null) {
        process.exitCode = 1;
    }
    if (options.debug) {
        console.log(JSON.stringify(bundle, null, 2));
    }
    else {
        console.log(bundle === null || bundle === void 0 ? void 0 : bundle.bundleHash);
    }
}
async function readBundleAction(bundleHash, options) {
    const opts = {
        ...parseConnectionOptions(options),
        bundleHash,
    };
    const bundle = await http_1.checkBundle(opts);
    if (bundle.type === 'error') {
        process.exitCode = 1;
    }
    console.log(JSON.stringify(bundle, null, 2));
}
async function analysisBundleAction(bundleHash, options) {
    const opts = {
        ...parseConnectionOptions(options),
        bundleHash,
    };
    const bundle = await analysis_1.analyzeBundle(opts);
    console.log(JSON.stringify(bundle, null, 2));
}
function enhanceCommonOptions(command) {
    return command
        .requiredOption('--url <url>', 'service URL')
        .requiredOption('--token <hash>', 'user token')
        .option('--org <string>', 'organization')
        .option('--source <string>', 'source identifier', 'code-client')
        .option('-H, --headers [string...]', 'custom headers e.g. "X-Custom-Header: some value". Can have multiple values diveded by space')
        .option('--debug', 'enable debug mode');
}
const program = new commander_1.Command();
program.name('CLI').version('0.1.0').description('Code Client API');
const filtersCommand = new commander_1.Command('filters').description('get supported file filters').action(filtersAction);
program.addCommand(enhanceCommonOptions(filtersCommand));
const createCommand = new commander_1.Command('bundle:create')
    .description('create a new bundle and return its ID with meta info')
    .option('--patterns [string...]', 'supported file patterns')
    .option('--ignore [path...]', 'ignored path glob')
    .requiredOption('--path [path...]', 'source code dir')
    .action(createBundleAction);
program.addCommand(enhanceCommonOptions(createCommand));
const checkCommand = new commander_1.Command('bundle:check')
    .description('read existing bundle and return its ID with meta info')
    .argument('<bundleId>', 'bundle identifier')
    .action(readBundleAction);
program.addCommand(enhanceCommonOptions(checkCommand));
const analysisCommand = new commander_1.Command('analysis:bundle')
    .description('run analysis for existing bundle')
    .argument('<bundleId>', 'bundle identifier')
    .action(analysisBundleAction);
program.addCommand(enhanceCommonOptions(analysisCommand));
/** Bundle upload process is started with provided data */
emitter_1.emitter.on('uploadBundleProgress', (processed, total) => {
    console.log(`Upload bundle progress: ${processed}/${total}`);
});
emitter_1.emitter.on('analyseProgress', (data) => {
    console.log(`${data.status} : ${data.progress * 100}%`);
});
// emitter.on('apiRequestLog', (message: string) => {
//   console.log(message);
// });
async function main() {
    await program.parseAsync(process.argv);
}
main().catch(err => {
    console.error(err);
});
//# sourceMappingURL=cli.js.map